package com.ruoyi.mall.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallAppOrderOrder;
import com.ruoyi.mall.domain.vo.MallAppOrderGoodsExportVO;

/**
 * app-线下订单Mapper接口
 *
 * @author ruoyi
 * @date 2024-06-29
 */
public interface MallAppOrderOrderMapper
{
    /**
     * 查询app-线下订单
     *
     * @param id app-线下订单主键
     * @return app-线下订单
     */
    public MallAppOrderOrder selectMallAppOrderOrderById(Long id);

    /**
     * 查询app-线下订单列表
     *
     * @param mallAppOrderOrder app-线下订单
     * @return app-线下订单集合
     */
    public List<MallAppOrderOrder> selectMallAppOrderOrderList(MallAppOrderOrder mallAppOrderOrder);

    /**
     * 新增app-线下订单
     *
     * @param mallAppOrderOrder app-线下订单
     * @return 结果
     */
    public int insertMallAppOrderOrder(MallAppOrderOrder mallAppOrderOrder);

    /**
     * 修改app-线下订单
     *
     * @param mallAppOrderOrder app-线下订单
     * @return 结果
     */
    public int updateMallAppOrderOrder(MallAppOrderOrder mallAppOrderOrder);

    /**
     * 删除app-线下订单
     *
     * @param id app-线下订单主键
     * @return 结果
     */
    public int deleteMallAppOrderOrderById(Long id);

    /**
     * 批量删除app-线下订单
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallAppOrderOrderByIds(Long[] ids);

    /**
     * 查询app-线下订单列表
     *
     * @param params 参数
     * @return app-线下订单集合
     */
    public List<Map<String, Object>> selectMallAppOrderOrderListByParams(Map<String, Object> params);

    /**
     * 订单商品列表
     *
     * @param mallAppOrderOrder app-线下订单
     * @return app-线下订单
     */
    public List<MallAppOrderGoodsExportVO> selectExportAppOrderList(MallAppOrderOrder mallAppOrderOrder);

    /**
     * 导出订单列表
     *
     * @param orderIds 订单ID
     * @return app-线下订单集合
     */
    public List<MallAppOrderGoodsExportVO> selectExportAppOrderAppOrderOrderList(Long[] orderIds);

    /**
     * 查询app-线上订单列表
     *
     * @param params 参数
     * @return app-线下订单集合
     */
    public List<Map<String, Object>> selectMallOrderOrderListByParams(Map<String, Object> params);
}
